==> haskell-websockets-0.12.5.3-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.12.5.3
id: websockets-0.12.5.3-Brc5VKiPtRc28yFc6vNhQ0
key: websockets-0.12.5.3-Brc5VKiPtRc28yFc6vNhQ0
license: BSD-3-Clause
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2018 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
abi: 9e33a2ac61a8e85d40db7813181c450a
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Extensions Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client
                Network.WebSockets.Connection.Options
                Network.WebSockets.Extensions.Description
                Network.WebSockets.Extensions.PermessageDeflate
                Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/websockets-0.12.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/websockets-0.12.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/websockets-0.12.5.3
hs-libraries: HSwebsockets-0.12.5.3-Brc5VKiPtRc28yFc6vNhQ0
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz binary-0.8.6.0
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 entropy-0.4.1.5-1eGU5wdZtMSH0Us8GoRymJ
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    streaming-commons-0.2.1.1-28hNvoSsYHXJrd00KOHsX9 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.12.5.3-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.12.5.3
id: websockets-0.12.5.3-1y7yBl1myKKHHNDnrAKDCR
key: websockets-0.12.5.3-1y7yBl1myKKHHNDnrAKDCR
license: BSD-3-Clause
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2018 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
abi: 45a3260607fa6fdd544f0bb65c5ac498
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Extensions Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client
                Network.WebSockets.Connection.Options
                Network.WebSockets.Extensions.Description
                Network.WebSockets.Extensions.PermessageDeflate
                Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/websockets-0.12.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/websockets-0.12.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/websockets-0.12.5.3
hs-libraries: HSwebsockets-0.12.5.3-1y7yBl1myKKHHNDnrAKDCR
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz binary-0.8.6.0
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 entropy-0.4.1.5-1eGU5wdZtMSH0Us8GoRymJ
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    streaming-commons-0.2.1.1-28hNvoSsYHXJrd00KOHsX9 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
